#!/bin/bash
# Installer script to install the VMService

VERSION="1.0.0"
INT_DIR=`pwd`
VMSERVICE="VMCLIEXE"
INIT_SCR="vmcli"
CONF_FILE="vmcli.conf"
PID_FILE="/var/run/vmcli"
MAN_FILE="vmcli.1"
WARNING="**********WARNING**********"

show_usage()
{
	echo "American Megatrends Inc."
	echo "Copyright (C) 2012"
	echo "Installer script for VMCLI Service - Version $VERSION"
	echo "Usage : ./installer.sh [options]"
	echo -e "-i,--install \t Installs the VMCLI in the system"
	echo -e "\t\t Please specify the install directory; otherwise current directory will be used"
	echo -e "-u,--uninstall \t Uninstalls the VMCLI from the system"
	echo -e "-h,--help \t Prints the help message of this script"
	echo -e "-v,--version \t Prints the version of this script"
}

install()
{
	if test -f $PID_FILE; then
		echo "VMCLI service is running"
		echo "Please stop the service to install"
		exit 0
	fi

	echo -n "Installing the VMCLI service... "
	if [ -n "$1" ]; then
		INT_DIR="$1"
	fi
	
	if [ ! -x "$INT_DIR"/$VMSERVICE ]; then
		echo "Failed."
		echo "VMCLI executable not found"
		exit 1
	fi

	if [ ! -f "$INT_DIR"/$INIT_SCR ]; then
		echo "Failed."
		echo "VMCLI service Init script not found"
		exit 1
	fi
	
	if [ ! -f "$INT_DIR"/$MAN_FILE ]; then
		echo "Failed."
		echo "VMCLI man file not found"
		exit 1
	fi
	
	if [ -f "$INT_DIR"/$CONF_FILE ]; then
		mkdir -p /etc/vmcli 2>/dev/null
		if [ $? == 0 ]; then
			cp "$INT_DIR"/$CONF_FILE /etc/vmcli	
		fi
	fi

	cp "$INT_DIR"/$VMSERVICE /usr/bin
	cp "$INT_DIR"/$INIT_SCR /etc/init.d
	cp "$INT_DIR"/$MAN_FILE /usr/local/share/man/man1
	
	if ! which wget >/dev/null; then
		echo $WARNING	
		echo "Wget is missing. VMCLI might not work properly without Wget"
		echo $WARNING
	fi
	
	echo "Success."
}

uninstall()
{
	if test -f $PID_FILE; then
		echo "VMCLI service is running"
		echo "Please stop the service to uninstall"
		exit 0
	fi

	if test -f /usr/bin/$VMSERVICE; then
		rm -rf /usr/bin/$VMSERVICE
	fi

	if test -f /etc/init.d/$INIT_SCR; then
		rm -rf /etc/init.d/$INIT_SCR
	fi
	
	if test -f /usr/local/man/man1/$MAN_FILE; then
		rm -rf /usr/local/man/man1/$MAN_FILE
	fi
	
	if test -d /etc/vmcli; then
		rm -rf /etc/vmcli
	fi

	echo "Uninstalling the VMCLI service... Success."
}

chkconfig()
{
   case "$1" in
	"-i" | "--install")
	install $2 
	;;
	"-u" | "--uninstall")
	uninstall
	;;
	"-v" | "--version")
	echo "Version $VERSION"
	exit 0
	;;
	"-h" | "--help")
	show_usage
	exit 0
	;;
	*)
	show_usage
   esac
}

chkconfig $1 $2
exit 0
