echo off
@cls
@rem  ****************************************************************
@rem  *
@rem  * File Name: installer.bat
@rem  *
@rem  * Author: Muthuchamy.k (muthusamyk@amiindia.co.in)
@rem  ****************************************************************
@rem
@rem
@echo ****************************************************************
@echo *           MegaRAC SP-X                                       *
@echo ****************************************************************
@echo Install/Uninstall process for VMCLI
@echo.
@echo.

@rem Process command line arguments
	
SET "WARNING=**********WARNING**********"

if ""=="%1" (
        goto LESS_ARGS
) else if not ""=="%3" (
        goto TOOMANY_ARGS
)
set options=%1
set service="VMCLI"

@rem Detecting OS architecture
if "%processor_architecture%"=="AMD64" (
 SET "PROGFILES=%ProgramFiles(x86)%"
) else if "%PROCESSOR_ARCHITEW6432%"=="AMD64" (
 SET "PROGFILES=%ProgramFiles(x86)%"
) else if "%processor_architecture%"=="x86" (
 SET "PROGFILES=%ProgramFiles%"
) else (
 @echo unknown...
 goto END
)
echo %PROGFILES%
if "%options%" == "-h" (
	goto USAGE
) else if "%options%" == "-v" (
	goto VERSION
) else if "%options%" == "-i" (
	goto INSTALL
) else if "%options%" == "-u" (
	for /F "tokens=3 delims=: " %%H in ('sc query %service% ^| findstr "        STATE"') do (
		if /I "%%H" NEQ "RUNNING" (
			goto UNINSTALL
		) else (
			goto UNINT_FAILED_SERVICE_RUNNING
		)
    )
	goto UNINSTALL
)

@echo "Invalid argument"
@echo.
goto USAGE

@rem Install the VMCLI service
:INSTALL
@rem Set the Install directory
set INSTALL_DIR=%cd%
if not "" == "%2" (
set INSTALL_DIR=%2
)

if not exist "%INSTALL_DIR%"\VMCLI.exe (
goto VMCLI_NOT_FOUND
)

if not exist "%INSTALL_DIR%"\vmcli.conf (
goto VMCLI_CONF_NOT_FOUND
)

set CUR_DIR=%cd%
cd /D %PROGFILES%
mkdir VMCLI
if not "%ERRORLEVEL%" == "0" (
@echo VMCLI service is already installed
@echo Please uninstall the VMCLI service to reinstall
cd /D "%CUR_DIR%"
goto END
)
cd /D %INSTALL_DIR%
@echo.
@echo Installing the VMCLI...
copy /Y /V "%INSTALL_DIR%\vmcli.conf" %systemroot%
set DEST=%PROGFILES%
copy /Y /V "%INSTALL_DIR%\VMCLI.exe" "%DEST%\VMCLI\"
copy /Y /V "%INSTALL_DIR%\wget.exe" "%DEST%\VMCLI\"
sc create VMCLI binpath= "%PROGFILES%\VMCLI\VMCLI.exe"
sc description VMCLI "Allows User to redirect the Virtual Media devices like Floppy,CD,HardDisk."
goto INT_SUCCESS

@rem Uninstall the VMCLI service
:UNINSTALL
@echo Uninstalling the VMCLI...
set CUR_DIR=%cd%
cd /D %PROGFILES%
rmdir /s /q VMCLI
sc delete VMCLI
del /S /Q "%systemroot%\vmcli.conf"
cd /D "%CUR_DIR%"
goto UNINT_SUCCESS

:INT_SUCCESS
@echo.
@echo Installation process completed successfully
if not exist "%INSTALL_DIR%"\wget.exe (
@echo.
@echo %WARNING%
@echo wget.exe is missing. VMCLI might not work properly without wget.exe
@echo %WARNING%
)
goto END

:INT_FAILED
@echo.
@echo Installation process failed
goto END

:UNINT_SUCCESS
@echo.
@echo Uninstallation process completed successfully
goto END

:UNINT_FAILED
@echo.
@echo Uninstallation process failed
goto END

:UNINT_FAILED_SERVICE_RUNNING
echo.
@echo VMCLI service is running
@echo Please stop the service to uninstall
goto END
	
:LESS_ARGS
@echo.
echo ERROR: insufficient arguments supplied
@echo.
goto USAGE
	

:TOOMANY_ARGS
@echo.
echo ERROR: too many arguments were supplied
@echo.
goto USAGE

:VMCLI_CONF_NOT_FOUND
@echo.
@echo ERROR: vmcli.conf is missing inside "%INSTALL_DIR%" folder
goto END

:VMCLI_NOT_FOUND
@echo.
@echo ERROR: VMCLI.exe is missing inside "%INSTALL_DIR%" folder
goto END

	
:USAGE
@echo.
@echo usage: installer.bat [options]
@echo.
@echo options
@echo   -i	- Install the VMCLI service.
@echo             Please specify the directory which contains the VMCLI application.
@echo             Otherwise current directory will be used.
@echo.
@echo   -u	- Uninstall the VMCLI service.
@echo.
@echo   -h	- Displays Help message.
@echo.
@echo   -v	- Displays the Version of the installer script.
@echo.
goto END

:VERSION
@echo Version 1.0.0
goto END

:END
@echo.
